@@ -307,6 +307,77 @@ class Orders(Resource):
             ), xml_declaration=True, encoding='utf-8'
         )
 
+    def update_shipment(self, order_id, package):
+        headers = {
+            'Content-Type': "application/xml"
+        }
+        url = self.url + '/%s/shipping' % order_id
+        return self.connection.send_request(
+            method='POST',
+            url=url,
+            body=self.get_shipment_payload(package),
+            request_headers=headers
+        )
+
+    def get_shipment_payload(self, package):
+        """Shipment Update
+
+        :param package: {
+            "tracking_number": "",
+            "tracking_url": "",
+            "carrier": "",
+            "carrier_service": '',
+            "ship_date_time": '',
+            "items": [{
+                "line_number": "",
+                "quantity": 2,
+                "status": "Shipped",
+                "uom": "Each",
+            }]
+        }
+        """
+        element = ElementMaker(
+            namespace='http://walmart.com/mp/v2/orders',
+            nsmap={
+                'ns2': 'http://walmart.com/mp/v2/orders',
+                'ns3': 'http://walmart.com/'
+            }
+        )
+        order_lines = []
+        for item in package['items']:
+            tracking_info = element(
+                'trackingInfo',
+                element('shipDateTime', package.get('ship_date_time', '')),
+                element('carrierName', element('carrier', package['carrier'])),
+                element('methodCode', package['carrier_service']),
+                element('trackingNumber', package['tracking_number']),
+                element('trackingURL', package.get('tracking_url', '')),
+            )
+            status_info = element(
+                'orderLineStatuses',
+                element(
+                    'orderLineStatus',
+                    element('status', item['status']),
+                    element(
+                        'statusQuantity',
+                        element('unitOfMeasurement', item['uom']),
+                        element('amount', str(item['quantity']))
+                    ),
+                    tracking_info
+                )
+            )
+            order_lines.append(element(
+                'orderLine',
+                element('lineNumber', item['line_number']),
+                status_info
+            ))
+        shipment_data = element(
+            'orderShipment', element('orderLines', *order_lines)
+        )
+        return etree.tostring(
+            shipment_data, xml_declaration=True, encoding='utf-8'
+        )
+
 
 class Report(Resource):
     """
